var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { ApplicationRef, Component, ComponentFactoryResolver, ContentChildren, Directive, ElementRef, EventEmitter, Injectable, Input, NgModule, NgZone, Renderer2, TemplateRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/combineLatest';
import 'rxjs/add/operator/takeUntil';
import { CommonModule } from '@angular/common';
var NzbAlertDirective = (function () {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} ngZone
     */
    function NzbAlertDirective(elementRef, renderer, ngZone) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.initiallyOpen = true;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    Object.defineProperty(NzbAlertDirective.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbAlertDirective.prototype, "status", {
        /**
         * @return {?}
         */
        get: function () {
            return this.statusSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbAlertDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            var /** @type {?} */ comment = _this.renderer.createComment('alert placeholder');
            _this.$el = jQuery(_this.elementRef.nativeElement);
            _this.$placeholder = jQuery(comment);
            _this.$el.before(_this.$placeholder);
            if (_this.initiallyOpen) {
                _this.open();
            }
            else {
                _this.close();
            }
        });
    };
    /**
     * @return {?}
     */
    NzbAlertDirective.prototype.open = function () {
        var _this = this;
        this.ngZone.runOutsideAngular(function () {
            _this.$placeholder.after(_this.$el);
            _this.statusSubject.next('opening');
            _this.$el.one('close.bs.alert', function (event) {
                _this.ngZone.run(function () {
                    _this.eventsSubject.next(event);
                    _this.statusSubject.next('closing');
                });
            });
            _this.$el.one('closed.bs.alert', function (event) {
                _this.ngZone.run(function () {
                    _this.eventsSubject.next(event);
                    _this.statusSubject.next('closed');
                });
            });
            _this.$el.alert();
            _this.ngZone.run(function () {
                if (!_this.$el.hasClass('fade')) {
                    _this.statusSubject.next('open');
                    return;
                }
                _this.$el.one('webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend', function (event) {
                    _this.ngZone.run(function () {
                        _this.statusSubject.next('open');
                    });
                });
                setTimeout(function () {
                    _this.$el.addClass('show');
                }, 100);
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAlertDirective.prototype.close = function () {
        if ('uninitialized' === this.statusSubject.value) {
            this.$el.remove();
            this.statusSubject.next('closed');
            return;
        }
        if ('open' !== this.statusSubject.value) {
            return;
        }
        jQuery(this.elementRef.nativeElement).alert('close');
    };
    return NzbAlertDirective;
}());
NzbAlertDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbAlert]',
                exportAs: 'nzbAlert'
            },] },
];
/**
 * @nocollapse
 */
NzbAlertDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: NgZone, },
]; };
NzbAlertDirective.propDecorators = {
    'initiallyOpen': [{ type: Input },],
};
var NzbCarouselDirective = (function () {
    /**
     * @param {?} elementRef
     * @param {?} ngZone
     */
    function NzbCarouselDirective(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.animatingSubject = new BehaviorSubject(false);
        this.pausedSubject = new BehaviorSubject(false);
        this.indexSubject = new BehaviorSubject(-1);
        this.eventsSubject = new Subject();
        this.dataSubject = new BehaviorSubject(null);
    }
    Object.defineProperty(NzbCarouselDirective.prototype, "animating", {
        /**
         * @return {?}
         */
        get: function () {
            return this.animatingSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbCarouselDirective.prototype, "paused", {
        /**
         * @return {?}
         */
        get: function () {
            return this.pausedSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbCarouselDirective.prototype, "index", {
        /**
         * @return {?}
         */
        get: function () {
            return this.indexSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbCarouselDirective.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbCarouselDirective.prototype, "data", {
        /**
         * @return {?}
         */
        get: function () {
            return this.dataSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    ;
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.updateDataProperties = function () {
        var /** @type {?} */ data = this.$el.data('bs.carousel');
        this.pausedSubject.next(data._isPaused);
        this.dataSubject.next(data);
    };
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.$el = jQuery(_this.elementRef.nativeElement);
            var /** @type {?} */ active = jQuery('.carousel-inner .carousel-item', _this.$el).index('.active');
            _this.indexSubject.next(active);
            _this.ngZone.runOutsideAngular(function () {
                _this.$el.on('slide.bs.carousel slid.bs.carousel mouseenter mouseleave touchend', function (event) {
                    _this.ngZone.run(function () {
                        if ('bs.carousel' === event.namespace) {
                            _this.eventsSubject.next(event);
                            if ('slid' === event.type) {
                                _this.indexSubject.next(event.to);
                                _this.animatingSubject.next(false);
                            }
                            else {
                                _this.animatingSubject.next(true);
                            }
                        }
                        _this.updateDataProperties();
                    });
                });
                _this.$el.carousel();
                _this.updateDataProperties();
            });
        });
    };
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.cycle = function () {
        this.$el.carousel('cycle');
        this.updateDataProperties();
    };
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.pause = function () {
        this.$el.carousel('pause');
        this.updateDataProperties();
    };
    /**
     * @param {?} index
     * @return {?}
     */
    NzbCarouselDirective.prototype.slideTo = function (index) {
        this.$el.carousel(index);
        this.updateDataProperties();
    };
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.prev = function () {
        this.$el.carousel('prev');
        this.updateDataProperties();
    };
    /**
     * @return {?}
     */
    NzbCarouselDirective.prototype.next = function () {
        this.$el.carousel('next');
        this.updateDataProperties();
    };
    return NzbCarouselDirective;
}());
NzbCarouselDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbCarousel]',
                exportAs: 'nzbCarousel'
            },] },
];
/**
 * @nocollapse
 */
NzbCarouselDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: NgZone, },
]; };
var NzbCollapseDirective = (function () {
    /**
     * @param {?} elementRef
     * @param {?} ngZone
     */
    function NzbCollapseDirective(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    Object.defineProperty(NzbCollapseDirective.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbCollapseDirective.prototype, "status", {
        /**
         * @return {?}
         */
        get: function () {
            return this.statusSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbCollapseDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            var /** @type {?} */ $el = jQuery(_this.elementRef.nativeElement);
            var /** @type {?} */ shown = $el.data('toggle') === true;
            _this.ngZone.runOutsideAngular(function () {
                $el.on('show.bs.collapse shown.bs.collapse hide.bs.collapse hidden.bs.collapse', function (event) {
                    _this.ngZone.run(function () {
                        _this.eventsSubject.next(event);
                        _this.statusSubject.next(event.type);
                    });
                });
                $el.collapse();
                _this.statusSubject.next(shown ? 'shown' : 'hidden');
            });
        });
    };
    /**
     * @return {?}
     */
    NzbCollapseDirective.prototype.ngOnDestroy = function () {
        var _this = this;
        setTimeout(function () {
            var /** @type {?} */ $el = jQuery(_this.elementRef.nativeElement);
            $el.off('show.bs.collapse shown.bs.collapse hide.bs.collapse hidden.bs.collapse');
        });
    };
    /**
     * @return {?}
     */
    NzbCollapseDirective.prototype.toggle = function () {
        jQuery(this.elementRef.nativeElement).collapse('toggle');
    };
    /**
     * @return {?}
     */
    NzbCollapseDirective.prototype.show = function () {
        jQuery(this.elementRef.nativeElement).collapse('show');
    };
    /**
     * @return {?}
     */
    NzbCollapseDirective.prototype.hide = function () {
        jQuery(this.elementRef.nativeElement).collapse('hide');
    };
    return NzbCollapseDirective;
}());
NzbCollapseDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbCollapse]',
                exportAs: 'nzbCollapse'
            },] },
];
/**
 * @nocollapse
 */
NzbCollapseDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: NgZone, },
]; };
var NzbDropdownDirective = (function () {
    /**
     * @param {?} ngZone
     * @param {?} elementRef
     */
    function NzbDropdownDirective(ngZone, elementRef) {
        this.ngZone = ngZone;
        this.elementRef = elementRef;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    Object.defineProperty(NzbDropdownDirective.prototype, "status", {
        /**
         * @return {?}
         */
        get: function () {
            return this.statusSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbDropdownDirective.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbDropdownDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.ngZone.runOutsideAngular(function () {
                jQuery(_this.elementRef.nativeElement).on('show.bs.dropdown shown.bs.dropdown hide.bs.dropdown hidden.bs.dropdown', function (event) {
                    _this.ngZone.run(function () {
                        _this.eventsSubject.next(event);
                        _this.statusSubject.next(event.type);
                    });
                });
            });
            _this.statusSubject.next('hidden');
        });
    };
    /**
     * @return {?}
     */
    NzbDropdownDirective.prototype.toggle = function () {
        jQuery(this.elementRef.nativeElement).dropdown('toggle');
    };
    /**
     * @return {?}
     */
    NzbDropdownDirective.prototype.update = function () {
        jQuery(this.elementRef.nativeElement).dropdown('update');
    };
    return NzbDropdownDirective;
}());
NzbDropdownDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbDropdown]',
                exportAs: 'nzbDropdown'
            },] },
];
/**
 * @nocollapse
 */
NzbDropdownDirective.ctorParameters = function () { return [
    { type: NgZone, },
    { type: ElementRef, },
]; };
var NzbDynamicContentComponent = (function () {
    function NzbDynamicContentComponent() {
    }
    return NzbDynamicContentComponent;
}());
NzbDynamicContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'nzb-dynamic-content',
                template: "<ng-content></ng-content>"
            },] },
];
/**
 * @nocollapse
 */
NzbDynamicContentComponent.ctorParameters = function () { return []; };
var NzbModalDirective = (function () {
    /**
     * @param {?} ngZone
     * @param {?} templateRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     */
    function NzbModalDirective(ngZone, templateRef, renderer, viewContainer, appRef, cfr) {
        this.ngZone = ngZone;
        this.templateRef = templateRef;
        this.renderer = renderer;
        this.viewContainer = viewContainer;
        this.appRef = appRef;
        this.cfr = cfr;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    Object.defineProperty(NzbModalDirective.prototype, "status", {
        /**
         * @return {?}
         */
        get: function () {
            return this.statusSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbModalDirective.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.createAndAppendModal = function () {
        var /** @type {?} */ viewRef = this.templateRef.createEmbeddedView(this);
        var /** @type {?} */ factory = this.cfr.resolveComponentFactory(NzbDynamicContentComponent);
        this.appRef.attachView(viewRef);
        this.componentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
        this.appRef.attachView(this.componentRef.hostView);
        this.renderer.appendChild(document.body, this.componentRef.location.nativeElement);
        return jQuery('.modal', this.componentRef.location.nativeElement);
    };
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.ngOnDestroy = function () {
        if (this.statusSubject.value === 'shown') {
            this.hide();
        }
    };
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.show = function () {
        var _this = this;
        if (this.statusSubject.value !== 'uninitialized') {
            return;
        }
        var /** @type {?} */ $el = this.createAndAppendModal();
        this.ngZone.runOutsideAngular(function () {
            $el.on('show.bs.modal shown.bs.modal hide.bs.modal hidden.bs.modal', function (event) {
                _this.ngZone.run(function () {
                    _this.eventsSubject.next(event);
                    _this.statusSubject.next(event.type);
                    if (event.type !== 'hidden') {
                        return;
                    }
                    $el.off('show.bs.modal shown.bs.modal hide.bs.modal hidden.bs.modal');
                    _this.componentRef.destroy();
                    _this.statusSubject.next('uninitialized');
                });
            });
            $el.modal({ show: true });
        });
    };
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.hide = function () {
        if (this.statusSubject.value !== 'shown') {
            return;
        }
        jQuery('.modal', this.componentRef.location.nativeElement).modal('hide');
    };
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.toggle = function () {
        if (this.statusSubject.value === 'shown') {
            this.hide();
        }
        else {
            this.show();
        }
    };
    /**
     * @return {?}
     */
    NzbModalDirective.prototype.handleUpdate = function () {
        if (this.statusSubject.value !== 'shown') {
            return;
        }
        jQuery('.modal', this.componentRef.location.nativeElement).modal('handleUpdate');
    };
    return NzbModalDirective;
}());
NzbModalDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbModal]',
                exportAs: 'nzbModal'
            },] },
];
/**
 * @nocollapse
 */
NzbModalDirective.ctorParameters = function () { return [
    { type: NgZone, },
    { type: TemplateRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
]; };
var NzbPopupOptions = (function () {
    function NzbPopupOptions() {
        this.animateOnDestroy = true;
    }
    return NzbPopupOptions;
}());
/**
 * @abstract
 */
var NzbAbstractPopup = (function () {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    function NzbAbstractPopup(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.viewContainer = viewContainer;
        this.appRef = appRef;
        this.cfr = cfr;
        this.ngZone = ngZone;
        this.defaultOptions = defaultOptions;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
        this.titleComponentRef = null;
        this.contentComponentRef = null;
        this.enabledSubject = new BehaviorSubject(true);
    }
    /**
     * @abstract
     * @return {?}
     */
    NzbAbstractPopup.prototype.getInputTitleTemplate = function () { };
    /**
     * @abstract
     * @return {?}
     */
    NzbAbstractPopup.prototype.getInputContentTemplate = function () { };
    /**
     * @abstract
     * @return {?}
     */
    NzbAbstractPopup.prototype.getInputOptions = function () { };
    Object.defineProperty(NzbAbstractPopup.prototype, "enabled", {
        /**
         * @return {?}
         */
        get: function () {
            return this.enabledSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbAbstractPopup.prototype, "status", {
        /**
         * @return {?}
         */
        get: function () {
            return this.statusSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbAbstractPopup.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbAbstractPopup.prototype, "data", {
        /**
         * @return {?}
         */
        get: function () {
            return jQuery(this.elementRef.nativeElement).data('bs.' + this.bsComponentName);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.getEventNames = function () {
        var _this = this;
        var /** @type {?} */ events = ['inserted', 'show', 'shown', 'hide', 'hidden'].map(function (type) {
            return type + '.bs.' + _this.bsComponentName;
        });
        return events.join(' ');
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.normalizeOptions = function () {
        var /** @type {?} */ appOptions = new NzbPopupOptions();
        var /** @type {?} */ inputOptions = this.getInputOptions();
        var /** @type {?} */ defaultOptions = this.defaultOptions;
        if (!inputOptions) {
            inputOptions = {};
        }
        if (!defaultOptions) {
            defaultOptions = {};
        }
        return Object.assign({}, appOptions, defaultOptions, inputOptions);
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.initPopup = function () {
        var _this = this;
        var /** @type {?} */ $el = jQuery(this.elementRef.nativeElement);
        var /** @type {?} */ factory = this.cfr.resolveComponentFactory(NzbDynamicContentComponent);
        var /** @type {?} */ inputTitle = this.getInputTitleTemplate();
        var /** @type {?} */ inputContentTemplate = this.getInputContentTemplate();
        var /** @type {?} */ inputOptions = this.getInputOptions();
        var /** @type {?} */ bsConfig = this.normalizeOptions();
        var /** @type {?} */ viewRef;
        if (!$el.attr('title')) {
            if (inputTitle instanceof TemplateRef) {
                viewRef = inputTitle.createEmbeddedView(this);
                this.appRef.attachView(viewRef);
                this.titleComponentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
                this.appRef.attachView(this.titleComponentRef.hostView);
                bsConfig.title = this.titleComponentRef.location.nativeElement;
                bsConfig.html = true;
            }
        }
        if (inputContentTemplate instanceof TemplateRef) {
            viewRef = inputContentTemplate.createEmbeddedView(this);
            this.appRef.attachView(viewRef);
            this.contentComponentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
            this.appRef.attachView(this.contentComponentRef.hostView);
            bsConfig.content = this.contentComponentRef.location.nativeElement;
            bsConfig.html = true;
        }
        this.ngZone.runOutsideAngular(function () {
            $el.on(_this.getEventNames(), function (event) {
                _this.ngZone.run(function () {
                    _this.eventsSubject.next(event);
                    _this.statusSubject.next(event.type);
                });
            });
        });
        $el[this.bsComponentName](bsConfig);
        this.statusSubject.next('hidden');
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.ngZone.runOutsideAngular(function () {
                _this.initPopup();
                _this.ngZone.run(function () { });
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.ngOnDestroy = function () {
        var _this = this;
        setTimeout(function () {
            var /** @type {?} */ $el = jQuery(_this.elementRef.nativeElement);
            var /** @type {?} */ reallyDispose = function () {
                $el[_this.bsComponentName]('dispose');
                if (_this.titleComponentRef) {
                    _this.titleComponentRef.destroy();
                }
                if (_this.contentComponentRef) {
                    _this.contentComponentRef.destroy();
                }
            };
            _this.ngZone.runOutsideAngular(function () {
                if (_this.statusSubject.value === 'shown' && _this.normalizeOptions().animateOnDestroy) {
                    $el.one('hidden.bs.' + _this.bsComponentName, function () {
                        reallyDispose();
                        _this.ngZone.run(function () { });
                    });
                    $el[_this.bsComponentName]('hide');
                }
                else {
                    reallyDispose();
                    _this.ngZone.run(function () { });
                }
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.toggle = function () {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('toggle');
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.show = function () {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('show');
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.hide = function () {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('hide');
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.enable = function () {
        var _this = this;
        this.ngZone.runOutsideAngular(function () {
            jQuery(_this.elementRef.nativeElement)[_this.bsComponentName]('enable');
            _this.ngZone.run(function () {
                _this.enabledSubject.next(true);
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.disable = function () {
        var _this = this;
        this.ngZone.runOutsideAngular(function () {
            jQuery(_this.elementRef.nativeElement)[_this.bsComponentName]('disable');
            _this.ngZone.run(function () {
                _this.enabledSubject.next(false);
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.toggleEnabled = function () {
        var _this = this;
        var /** @type {?} */ enabledNext = !this.enabledSubject.value;
        this.ngZone.runOutsideAngular(function () {
            jQuery(_this.elementRef.nativeElement)[_this.bsComponentName]('toggleEnabled');
            _this.ngZone.run(function () {
                _this.enabledSubject.next(enabledNext);
            });
        });
    };
    /**
     * @return {?}
     */
    NzbAbstractPopup.prototype.update = function () {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('update');
    };
    return NzbAbstractPopup;
}());
var NzbPopoverOptions = (function (_super) {
    __extends(NzbPopoverOptions, _super);
    function NzbPopoverOptions() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NzbPopoverOptions;
}(NzbPopupOptions));
NzbPopoverOptions.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NzbPopoverOptions.ctorParameters = function () { return []; };
var NzbPopoverDirective = (function (_super) {
    __extends(NzbPopoverDirective, _super);
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    function NzbPopoverDirective(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        var _this = _super.call(this, elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) || this;
        _this.nzbPopoverTitle = null;
        _this.nzbPopoverContent = null;
        _this.nzbPopoverOptions = null;
        _this.bsComponentName = 'popover';
        return _this;
    }
    /**
     * @return {?}
     */
    NzbPopoverDirective.prototype.getInputTitleTemplate = function () {
        return this.nzbPopoverTitle;
    };
    /**
     * @return {?}
     */
    NzbPopoverDirective.prototype.getInputContentTemplate = function () {
        return this.nzbPopoverContent;
    };
    /**
     * @return {?}
     */
    NzbPopoverDirective.prototype.getInputOptions = function () {
        return this.nzbPopoverOptions;
    };
    return NzbPopoverDirective;
}(NzbAbstractPopup));
NzbPopoverDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbPopover]',
                exportAs: 'nzbPopover'
            },] },
];
/**
 * @nocollapse
 */
NzbPopoverDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
    { type: NgZone, },
    { type: NzbPopoverOptions, },
]; };
NzbPopoverDirective.propDecorators = {
    'nzbPopoverTitle': [{ type: Input },],
    'nzbPopoverContent': [{ type: Input },],
    'nzbPopoverOptions': [{ type: Input },],
};
/**
 * @abstract
 */
var NzbAbstractTab = (function () {
    /**
     * @param {?} elementRef
     */
    function NzbAbstractTab(elementRef) {
        this.elementRef = elementRef;
    }
    Object.defineProperty(NzbAbstractTab.prototype, "data", {
        /**
         * @return {?}
         */
        get: function () {
            return this.tabData;
        },
        /**
         * @param {?} tabData
         * @return {?}
         */
        set: function (tabData) {
            this.tabData = tabData;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbAbstractTab.prototype, "el", {
        /**
         * @return {?}
         */
        get: function () {
            return this.elementRef.nativeElement;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @abstract
     * @return {?}
     */
    NzbAbstractTab.prototype.id = function () { };
    return NzbAbstractTab;
}());
var NzbTabDirective = (function (_super) {
    __extends(NzbTabDirective, _super);
    /**
     * @param {?} elementRef
     */
    function NzbTabDirective(elementRef) {
        return _super.call(this, elementRef) || this;
    }
    Object.defineProperty(NzbTabDirective.prototype, "id", {
        /**
         * @return {?}
         */
        get: function () {
            return this.nzbTab;
        },
        enumerable: true,
        configurable: true
    });
    return NzbTabDirective;
}(NzbAbstractTab));
NzbTabDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTab]'
            },] },
];
/**
 * @nocollapse
 */
NzbTabDirective.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
NzbTabDirective.propDecorators = {
    'nzbTab': [{ type: Input, args: ['nzbTab',] },],
};
var NzbTabPaneDirective = (function (_super) {
    __extends(NzbTabPaneDirective, _super);
    /**
     * @param {?} elementRef
     */
    function NzbTabPaneDirective(elementRef) {
        return _super.call(this, elementRef) || this;
    }
    Object.defineProperty(NzbTabPaneDirective.prototype, "id", {
        /**
         * @return {?}
         */
        get: function () {
            return this.nzbTabPane;
        },
        enumerable: true,
        configurable: true
    });
    return NzbTabPaneDirective;
}(NzbAbstractTab));
NzbTabPaneDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTabPane]',
                exportAs: 'nzbTabPane'
            },] },
];
/**
 * @nocollapse
 */
NzbTabPaneDirective.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
NzbTabPaneDirective.propDecorators = {
    'nzbTabPane': [{ type: Input, args: ['nzbTabPane',] },],
};
var NzbTabData = (function () {
    /**
     * @param {?} tab
     */
    function NzbTabData(tab) {
        this.status = null;
        this.active = false;
        this.visible = false;
        this.tab = tab;
        this.id = tab.id;
    }
    return NzbTabData;
}());
var NzbTabsComponent = (function () {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} ngZone
     */
    function NzbTabsComponent(elementRef, renderer, ngZone) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.animation = true;
        this.ngUnsubscribe = new EventEmitter();
        this.tabsMap = new Map();
        this.tabsSubject = new BehaviorSubject([]);
        this.activeTabSubject = new BehaviorSubject(null);
        this.eventsSubject = new Subject();
    }
    Object.defineProperty(NzbTabsComponent.prototype, "tabs", {
        /**
         * @return {?}
         */
        get: function () {
            return this.tabsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbTabsComponent.prototype, "activeTab", {
        /**
         * @return {?}
         */
        get: function () {
            return this.activeTabSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzbTabsComponent.prototype, "events", {
        /**
         * @return {?}
         */
        get: function () {
            return this.eventsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NzbTabsComponent.prototype.init = function () {
        var _this = this;
        var /** @type {?} */ tabs = [];
        var /** @type {?} */ ids = [];
        var /** @type {?} */ activeId = null;
        var /** @type {?} */ activeTab;
        this.tabsMap.clear();
        this.ngZone.runOutsideAngular(function () {
            jQuery(_this.elementRef.nativeElement).on('show.bs.tab shown.bs.tab hide.bs.tab hidden.bs.tab', function (event) {
                _this.ngZone.run(function () {
                    var /** @type {?} */ id = jQuery(event.target).attr('nzbTab');
                    var /** @type {?} */ data = _this.tabsMap.get(id) || null;
                    var /** @type {?} */ tabs = [];
                    if (data) {
                        data.status = event.type;
                        switch (event.type) {
                            case 'hidden':
                                data.visible = false;
                                break;
                            case 'hide':
                                data.active = false;
                                break;
                            case 'show':
                                data.active = true;
                                data.visible = true;
                                _this.activeTabSubject.next(data);
                                break;
                        }
                    }
                    _this.tabsMap.forEach(function (entry) {
                        tabs.push(entry);
                    });
                    _this.tabsSubject.next(tabs);
                    _this.eventsSubject.next(event);
                });
            });
        });
        this.nzbTabDirectives.forEach(function (tab) {
            var /** @type {?} */ tabData = new NzbTabData(tab);
            _this.nzbTabPaneDirectives.forEach(function (pane) {
                if (pane.id === tab.id) {
                    ids.push(tab.id);
                    tabData.pane = pane;
                    tabs.push(tabData);
                    _this.tabsMap.set(tab.id, tabData);
                }
            });
        });
        if (tabs.length > 0) {
            if (typeof this.shownTab === 'string') {
                if (ids.indexOf(this.shownTab) > -1) {
                    activeId = this.shownTab;
                }
            }
            else {
                if (typeof this.shownTab === 'number') {
                    if (this.shownTab < ids.length) {
                        activeId = ids[this.shownTab];
                    }
                }
            }
            if (!activeId) {
                activeId = tabs[0].tab.id;
            }
        }
        tabs.forEach(function (tab) {
            var /** @type {?} */ paneId = _this.uniqueId + '-' + tab.id;
            var /** @type {?} */ tabId = paneId + '-tab';
            tab.tab.data = tab;
            if (!tab.pane) {
                return;
            }
            tab.pane.data = tab;
            _this.renderer.setAttribute(tab.pane.el, 'id', paneId);
            _this.renderer.setAttribute(tab.pane.el, 'role', 'tabpanel');
            _this.renderer.setAttribute(tab.pane.el, 'aria-labelledby', tabId);
            _this.renderer.addClass(tab.pane.el, 'tab-pane');
            if (_this.animation) {
                _this.renderer.addClass(tab.pane.el, 'fade');
            }
            if (activeId === tab.id) {
                _this.renderer.addClass(tab.pane.el, 'active');
                _this.renderer.addClass(tab.tab.el, 'active');
                if (_this.animation) {
                    _this.renderer.addClass(tab.pane.el, 'show');
                }
            }
            _this.renderer.setAttribute(tab.tab.el, 'role', 'tab');
            _this.renderer.setAttribute(tab.tab.el, 'href', '#' + paneId);
            _this.renderer.setAttribute(tab.tab.el, 'aria-controls', paneId);
            _this.renderer.setAttribute(tab.tab.el, 'aria-expanded', 'false');
            _this.renderer.setAttribute(tab.tab.el, 'id', tabId);
            _this.renderer.setAttribute(tab.tab.el, 'data-toggle', 'tab');
            if (activeId === tab.id) {
                activeTab = tab;
            }
        });
        if (activeTab) {
            this.activeTabSubject.next(activeTab);
        }
        this.tabsSubject.next(tabs);
    };
    /**
     * @return {?}
     */
    NzbTabsComponent.prototype.ngOnInit = function () {
        this.uniqueId = this.uniqueId || 'nzb-tabs-' + Math.random().toString().replace('.', '');
    };
    /**
     * @return {?}
     */
    NzbTabsComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        setTimeout(function () {
            Observable.combineLatest(_this.nzbTabDirectives.changes, _this.nzbTabPaneDirectives.changes)
                .takeUntil(_this.ngUnsubscribe)
                .subscribe(function () {
                console.log('got here ngAfterContentInit');
            });
            _this.init();
        });
    };
    /**
     * @param {?} id
     * @return {?}
     */
    NzbTabsComponent.prototype.show = function (id) {
        var /** @type {?} */ tab = this.tabsMap.get(id);
        if (tab) {
            jQuery(tab.tab.el).tab('show');
        }
    };
    return NzbTabsComponent;
}());
NzbTabsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nzb-tabs',
                exportAs: 'nzbTabs',
                template: "<ng-content></ng-content>"
            },] },
];
/**
 * @nocollapse
 */
NzbTabsComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: NgZone, },
]; };
NzbTabsComponent.propDecorators = {
    'animation': [{ type: Input },],
    'uniqueId': [{ type: Input },],
    'shownTab': [{ type: Input },],
    'nzbTabDirectives': [{ type: ContentChildren, args: [NzbTabDirective,] },],
    'nzbTabPaneDirectives': [{ type: ContentChildren, args: [NzbTabPaneDirective,] },],
};
var NzbTooltipOptions = (function (_super) {
    __extends(NzbTooltipOptions, _super);
    function NzbTooltipOptions() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NzbTooltipOptions;
}(NzbPopupOptions));
NzbTooltipOptions.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NzbTooltipOptions.ctorParameters = function () { return []; };
var NzbTooltipDirective = (function (_super) {
    __extends(NzbTooltipDirective, _super);
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    function NzbTooltipDirective(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        var _this = _super.call(this, elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) || this;
        _this.nzbTooltipTitle = null;
        _this.nzbTooltipOptions = null;
        _this.bsComponentName = 'tooltip';
        return _this;
    }
    /**
     * @return {?}
     */
    NzbTooltipDirective.prototype.getInputTitleTemplate = function () {
        return this.nzbTooltipTitle;
    };
    /**
     * @return {?}
     */
    NzbTooltipDirective.prototype.getInputContentTemplate = function () {
        return null;
    };
    /**
     * @return {?}
     */
    NzbTooltipDirective.prototype.getInputOptions = function () {
        return this.nzbTooltipOptions;
    };
    return NzbTooltipDirective;
}(NzbAbstractPopup));
NzbTooltipDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTooltip]',
                exportAs: 'nzbTooltip'
            },] },
];
/**
 * @nocollapse
 */
NzbTooltipDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
    { type: NgZone, },
    { type: NzbTooltipOptions, },
]; };
NzbTooltipDirective.propDecorators = {
    'nzbTooltipTitle': [{ type: Input },],
    'nzbTooltipOptions': [{ type: Input },],
};
var NzbModule = (function () {
    function NzbModule() {
    }
    return NzbModule;
}());
NzbModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NzbAlertDirective,
                    NzbCarouselDirective,
                    NzbCollapseDirective,
                    NzbDynamicContentComponent,
                    NzbModalDirective,
                    NzbPopoverDirective,
                    NzbTooltipDirective,
                    NzbTabsComponent,
                    NzbTabPaneDirective,
                    NzbTabDirective,
                    NzbDropdownDirective
                ],
                exports: [
                    NzbAlertDirective,
                    NzbCarouselDirective,
                    NzbCollapseDirective,
                    NzbDynamicContentComponent,
                    NzbModalDirective,
                    NzbPopoverDirective,
                    NzbTooltipDirective,
                    NzbTabsComponent,
                    NzbTabPaneDirective,
                    NzbTabDirective,
                    NzbDropdownDirective
                ],
                providers: [
                    NzbPopoverOptions,
                    NzbTooltipOptions
                ],
                entryComponents: [
                    NzbDynamicContentComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NzbModule.ctorParameters = function () { return []; };
/**
 * Angular library starter.
 * Build an Angular library compatible with AoT compilation & Tree shaking.
 * Written by Roberto Simonetti.
 * MIT license.
 * https://github.com/robisim74/nowzoo-angular-bootstrap-lite
 */
/**
 * Entry point for all public APIs of the package.
 */
/**
 * Generated bundle index. Do not edit.
 */
export { NzbAlertDirective, NzbCarouselDirective, NzbCollapseDirective, NzbDropdownDirective, NzbModalDirective, NzbPopoverDirective, NzbPopoverOptions, NzbTabsComponent, NzbTabPaneDirective, NzbTabDirective, NzbTooltipDirective, NzbTooltipOptions, NzbModule, NzbAbstractPopup as ɵa, NzbDynamicContentComponent as ɵd, NzbPopupOptions as ɵb, NzbAbstractTab as ɵc };
//# sourceMappingURL=nowzoo-angular-bootstrap-lite.es5.js.map
