import { ApplicationRef, Component, ComponentFactoryResolver, ContentChildren, Directive, ElementRef, EventEmitter, Injectable, Input, NgModule, NgZone, Renderer2, TemplateRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/combineLatest';
import 'rxjs/add/operator/takeUntil';
import { CommonModule } from '@angular/common';

class NzbAlertDirective {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} ngZone
     */
    constructor(elementRef, renderer, ngZone) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.initiallyOpen = true;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get status() {
        return this.statusSubject.asObservable();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            const /** @type {?} */ comment = this.renderer.createComment('alert placeholder');
            this.$el = jQuery(this.elementRef.nativeElement);
            this.$placeholder = jQuery(comment);
            this.$el.before(this.$placeholder);
            if (this.initiallyOpen) {
                this.open();
            }
            else {
                this.close();
            }
        });
    }
    /**
     * @return {?}
     */
    open() {
        this.ngZone.runOutsideAngular(() => {
            this.$placeholder.after(this.$el);
            this.statusSubject.next('opening');
            this.$el.one('close.bs.alert', (event) => {
                this.ngZone.run(() => {
                    this.eventsSubject.next(event);
                    this.statusSubject.next('closing');
                });
            });
            this.$el.one('closed.bs.alert', (event) => {
                this.ngZone.run(() => {
                    this.eventsSubject.next(event);
                    this.statusSubject.next('closed');
                });
            });
            this.$el.alert();
            this.ngZone.run(() => {
                if (!this.$el.hasClass('fade')) {
                    this.statusSubject.next('open');
                    return;
                }
                this.$el.one('webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend', (event) => {
                    this.ngZone.run(() => {
                        this.statusSubject.next('open');
                    });
                });
                setTimeout(() => {
                    this.$el.addClass('show');
                }, 100);
            });
        });
    }
    /**
     * @return {?}
     */
    close() {
        if ('uninitialized' === this.statusSubject.value) {
            this.$el.remove();
            this.statusSubject.next('closed');
            return;
        }
        if ('open' !== this.statusSubject.value) {
            return;
        }
        jQuery(this.elementRef.nativeElement).alert('close');
    }
}
NzbAlertDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbAlert]',
                exportAs: 'nzbAlert'
            },] },
];
/**
 * @nocollapse
 */
NzbAlertDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: NgZone, },
];
NzbAlertDirective.propDecorators = {
    'initiallyOpen': [{ type: Input },],
};

class NzbCarouselDirective {
    /**
     * @param {?} elementRef
     * @param {?} ngZone
     */
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.animatingSubject = new BehaviorSubject(false);
        this.pausedSubject = new BehaviorSubject(false);
        this.indexSubject = new BehaviorSubject(-1);
        this.eventsSubject = new Subject();
        this.dataSubject = new BehaviorSubject(null);
    }
    /**
     * @return {?}
     */
    get animating() {
        return this.animatingSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get paused() {
        return this.pausedSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get index() {
        return this.indexSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get data() {
        return this.dataSubject.asObservable();
    }
    ;
    /**
     * @return {?}
     */
    updateDataProperties() {
        const /** @type {?} */ data = this.$el.data('bs.carousel');
        this.pausedSubject.next(data._isPaused);
        this.dataSubject.next(data);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.$el = jQuery(this.elementRef.nativeElement);
            let /** @type {?} */ active = jQuery('.carousel-inner .carousel-item', this.$el).index('.active');
            this.indexSubject.next(active);
            this.ngZone.runOutsideAngular(() => {
                this.$el.on('slide.bs.carousel slid.bs.carousel mouseenter mouseleave touchend', (event) => {
                    this.ngZone.run(() => {
                        if ('bs.carousel' === event.namespace) {
                            this.eventsSubject.next(event);
                            if ('slid' === event.type) {
                                this.indexSubject.next(event.to);
                                this.animatingSubject.next(false);
                            }
                            else {
                                this.animatingSubject.next(true);
                            }
                        }
                        this.updateDataProperties();
                    });
                });
                this.$el.carousel();
                this.updateDataProperties();
            });
        });
    }
    /**
     * @return {?}
     */
    cycle() {
        this.$el.carousel('cycle');
        this.updateDataProperties();
    }
    /**
     * @return {?}
     */
    pause() {
        this.$el.carousel('pause');
        this.updateDataProperties();
    }
    /**
     * @param {?} index
     * @return {?}
     */
    slideTo(index) {
        this.$el.carousel(index);
        this.updateDataProperties();
    }
    /**
     * @return {?}
     */
    prev() {
        this.$el.carousel('prev');
        this.updateDataProperties();
    }
    /**
     * @return {?}
     */
    next() {
        this.$el.carousel('next');
        this.updateDataProperties();
    }
}
NzbCarouselDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbCarousel]',
                exportAs: 'nzbCarousel'
            },] },
];
/**
 * @nocollapse
 */
NzbCarouselDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: NgZone, },
];

class NzbCollapseDirective {
    /**
     * @param {?} elementRef
     * @param {?} ngZone
     */
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get status() {
        return this.statusSubject.asObservable();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            const /** @type {?} */ $el = jQuery(this.elementRef.nativeElement);
            const /** @type {?} */ shown = $el.data('toggle') === true;
            this.ngZone.runOutsideAngular(() => {
                $el.on('show.bs.collapse shown.bs.collapse hide.bs.collapse hidden.bs.collapse', (event) => {
                    this.ngZone.run(() => {
                        this.eventsSubject.next(event);
                        this.statusSubject.next(event.type);
                    });
                });
                $el.collapse();
                this.statusSubject.next(shown ? 'shown' : 'hidden');
            });
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        setTimeout(() => {
            const /** @type {?} */ $el = jQuery(this.elementRef.nativeElement);
            $el.off('show.bs.collapse shown.bs.collapse hide.bs.collapse hidden.bs.collapse');
        });
    }
    /**
     * @return {?}
     */
    toggle() {
        jQuery(this.elementRef.nativeElement).collapse('toggle');
    }
    /**
     * @return {?}
     */
    show() {
        jQuery(this.elementRef.nativeElement).collapse('show');
    }
    /**
     * @return {?}
     */
    hide() {
        jQuery(this.elementRef.nativeElement).collapse('hide');
    }
}
NzbCollapseDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbCollapse]',
                exportAs: 'nzbCollapse'
            },] },
];
/**
 * @nocollapse
 */
NzbCollapseDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: NgZone, },
];

class NzbDropdownDirective {
    /**
     * @param {?} ngZone
     * @param {?} elementRef
     */
    constructor(ngZone, elementRef) {
        this.ngZone = ngZone;
        this.elementRef = elementRef;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    /**
     * @return {?}
     */
    get status() {
        return this.statusSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.ngZone.runOutsideAngular(() => {
                jQuery(this.elementRef.nativeElement).on('show.bs.dropdown shown.bs.dropdown hide.bs.dropdown hidden.bs.dropdown', (event) => {
                    this.ngZone.run(() => {
                        this.eventsSubject.next(event);
                        this.statusSubject.next(event.type);
                    });
                });
            });
            this.statusSubject.next('hidden');
        });
    }
    /**
     * @return {?}
     */
    toggle() {
        jQuery(this.elementRef.nativeElement).dropdown('toggle');
    }
    /**
     * @return {?}
     */
    update() {
        jQuery(this.elementRef.nativeElement).dropdown('update');
    }
}
NzbDropdownDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbDropdown]',
                exportAs: 'nzbDropdown'
            },] },
];
/**
 * @nocollapse
 */
NzbDropdownDirective.ctorParameters = () => [
    { type: NgZone, },
    { type: ElementRef, },
];

class NzbDynamicContentComponent {
}
NzbDynamicContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'nzb-dynamic-content',
                template: `<ng-content></ng-content>`
            },] },
];
/**
 * @nocollapse
 */
NzbDynamicContentComponent.ctorParameters = () => [];

class NzbModalDirective {
    /**
     * @param {?} ngZone
     * @param {?} templateRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     */
    constructor(ngZone, templateRef, renderer, viewContainer, appRef, cfr) {
        this.ngZone = ngZone;
        this.templateRef = templateRef;
        this.renderer = renderer;
        this.viewContainer = viewContainer;
        this.appRef = appRef;
        this.cfr = cfr;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
    }
    /**
     * @return {?}
     */
    get status() {
        return this.statusSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    createAndAppendModal() {
        const /** @type {?} */ viewRef = this.templateRef.createEmbeddedView(this);
        const /** @type {?} */ factory = this.cfr.resolveComponentFactory(NzbDynamicContentComponent);
        this.appRef.attachView(viewRef);
        this.componentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
        this.appRef.attachView(this.componentRef.hostView);
        this.renderer.appendChild(document.body, this.componentRef.location.nativeElement);
        return jQuery('.modal', this.componentRef.location.nativeElement);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.statusSubject.value === 'shown') {
            this.hide();
        }
    }
    /**
     * @return {?}
     */
    show() {
        if (this.statusSubject.value !== 'uninitialized') {
            return;
        }
        const /** @type {?} */ $el = this.createAndAppendModal();
        this.ngZone.runOutsideAngular(() => {
            $el.on('show.bs.modal shown.bs.modal hide.bs.modal hidden.bs.modal', (event) => {
                this.ngZone.run(() => {
                    this.eventsSubject.next(event);
                    this.statusSubject.next(event.type);
                    if (event.type !== 'hidden') {
                        return;
                    }
                    $el.off('show.bs.modal shown.bs.modal hide.bs.modal hidden.bs.modal');
                    this.componentRef.destroy();
                    this.statusSubject.next('uninitialized');
                });
            });
            $el.modal({ show: true });
        });
    }
    /**
     * @return {?}
     */
    hide() {
        if (this.statusSubject.value !== 'shown') {
            return;
        }
        jQuery('.modal', this.componentRef.location.nativeElement).modal('hide');
    }
    /**
     * @return {?}
     */
    toggle() {
        if (this.statusSubject.value === 'shown') {
            this.hide();
        }
        else {
            this.show();
        }
    }
    /**
     * @return {?}
     */
    handleUpdate() {
        if (this.statusSubject.value !== 'shown') {
            return;
        }
        jQuery('.modal', this.componentRef.location.nativeElement).modal('handleUpdate');
    }
}
NzbModalDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbModal]',
                exportAs: 'nzbModal'
            },] },
];
/**
 * @nocollapse
 */
NzbModalDirective.ctorParameters = () => [
    { type: NgZone, },
    { type: TemplateRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
];

class NzbPopupOptions {
    constructor() {
        this.animateOnDestroy = true;
    }
}

/**
 * @abstract
 */
class NzbAbstractPopup {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    constructor(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.viewContainer = viewContainer;
        this.appRef = appRef;
        this.cfr = cfr;
        this.ngZone = ngZone;
        this.defaultOptions = defaultOptions;
        this.eventsSubject = new Subject();
        this.statusSubject = new BehaviorSubject('uninitialized');
        this.titleComponentRef = null;
        this.contentComponentRef = null;
        this.enabledSubject = new BehaviorSubject(true);
    }
    /**
     * @abstract
     * @return {?}
     */
    getInputTitleTemplate() { }
    /**
     * @abstract
     * @return {?}
     */
    getInputContentTemplate() { }
    /**
     * @abstract
     * @return {?}
     */
    getInputOptions() { }
    /**
     * @return {?}
     */
    get enabled() {
        return this.enabledSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get status() {
        return this.statusSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get data() {
        return jQuery(this.elementRef.nativeElement).data('bs.' + this.bsComponentName);
    }
    /**
     * @return {?}
     */
    getEventNames() {
        const /** @type {?} */ events = ['inserted', 'show', 'shown', 'hide', 'hidden'].map((type) => {
            return type + '.bs.' + this.bsComponentName;
        });
        return events.join(' ');
    }
    /**
     * @return {?}
     */
    normalizeOptions() {
        const /** @type {?} */ appOptions = new NzbPopupOptions();
        let /** @type {?} */ inputOptions = this.getInputOptions();
        let /** @type {?} */ defaultOptions = this.defaultOptions;
        if (!inputOptions) {
            inputOptions = {};
        }
        if (!defaultOptions) {
            defaultOptions = {};
        }
        return Object.assign({}, appOptions, defaultOptions, inputOptions);
    }
    /**
     * @return {?}
     */
    initPopup() {
        const /** @type {?} */ $el = jQuery(this.elementRef.nativeElement);
        const /** @type {?} */ factory = this.cfr.resolveComponentFactory(NzbDynamicContentComponent);
        const /** @type {?} */ inputTitle = this.getInputTitleTemplate();
        const /** @type {?} */ inputContentTemplate = this.getInputContentTemplate();
        const /** @type {?} */ inputOptions = this.getInputOptions();
        const /** @type {?} */ bsConfig = this.normalizeOptions();
        let /** @type {?} */ viewRef;
        if (!$el.attr('title')) {
            if (inputTitle instanceof TemplateRef) {
                viewRef = inputTitle.createEmbeddedView(this);
                this.appRef.attachView(viewRef);
                this.titleComponentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
                this.appRef.attachView(this.titleComponentRef.hostView);
                bsConfig.title = this.titleComponentRef.location.nativeElement;
                bsConfig.html = true;
            }
        }
        if (inputContentTemplate instanceof TemplateRef) {
            viewRef = inputContentTemplate.createEmbeddedView(this);
            this.appRef.attachView(viewRef);
            this.contentComponentRef = factory.create(this.viewContainer.injector, [viewRef.rootNodes]);
            this.appRef.attachView(this.contentComponentRef.hostView);
            bsConfig.content = this.contentComponentRef.location.nativeElement;
            bsConfig.html = true;
        }
        this.ngZone.runOutsideAngular(() => {
            $el.on(this.getEventNames(), (event) => {
                this.ngZone.run(() => {
                    this.eventsSubject.next(event);
                    this.statusSubject.next(event.type);
                });
            });
        });
        $el[this.bsComponentName](bsConfig);
        this.statusSubject.next('hidden');
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.ngZone.runOutsideAngular(() => {
                this.initPopup();
                this.ngZone.run(() => { });
            });
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        setTimeout(() => {
            const /** @type {?} */ $el = jQuery(this.elementRef.nativeElement);
            const /** @type {?} */ reallyDispose = () => {
                $el[this.bsComponentName]('dispose');
                if (this.titleComponentRef) {
                    this.titleComponentRef.destroy();
                }
                if (this.contentComponentRef) {
                    this.contentComponentRef.destroy();
                }
            };
            this.ngZone.runOutsideAngular(() => {
                if (this.statusSubject.value === 'shown' && this.normalizeOptions().animateOnDestroy) {
                    $el.one('hidden.bs.' + this.bsComponentName, () => {
                        reallyDispose();
                        this.ngZone.run(() => { });
                    });
                    $el[this.bsComponentName]('hide');
                }
                else {
                    reallyDispose();
                    this.ngZone.run(() => { });
                }
            });
        });
    }
    /**
     * @return {?}
     */
    toggle() {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('toggle');
    }
    /**
     * @return {?}
     */
    show() {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('show');
    }
    /**
     * @return {?}
     */
    hide() {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('hide');
    }
    /**
     * @return {?}
     */
    enable() {
        this.ngZone.runOutsideAngular(() => {
            jQuery(this.elementRef.nativeElement)[this.bsComponentName]('enable');
            this.ngZone.run(() => {
                this.enabledSubject.next(true);
            });
        });
    }
    /**
     * @return {?}
     */
    disable() {
        this.ngZone.runOutsideAngular(() => {
            jQuery(this.elementRef.nativeElement)[this.bsComponentName]('disable');
            this.ngZone.run(() => {
                this.enabledSubject.next(false);
            });
        });
    }
    /**
     * @return {?}
     */
    toggleEnabled() {
        const /** @type {?} */ enabledNext = !this.enabledSubject.value;
        this.ngZone.runOutsideAngular(() => {
            jQuery(this.elementRef.nativeElement)[this.bsComponentName]('toggleEnabled');
            this.ngZone.run(() => {
                this.enabledSubject.next(enabledNext);
            });
        });
    }
    /**
     * @return {?}
     */
    update() {
        jQuery(this.elementRef.nativeElement)[this.bsComponentName]('update');
    }
}

class NzbPopoverOptions extends NzbPopupOptions {
}
NzbPopoverOptions.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NzbPopoverOptions.ctorParameters = () => [];

class NzbPopoverDirective extends NzbAbstractPopup {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    constructor(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        super(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions);
        this.nzbPopoverTitle = null;
        this.nzbPopoverContent = null;
        this.nzbPopoverOptions = null;
        this.bsComponentName = 'popover';
    }
    /**
     * @return {?}
     */
    getInputTitleTemplate() {
        return this.nzbPopoverTitle;
    }
    /**
     * @return {?}
     */
    getInputContentTemplate() {
        return this.nzbPopoverContent;
    }
    /**
     * @return {?}
     */
    getInputOptions() {
        return this.nzbPopoverOptions;
    }
}
NzbPopoverDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbPopover]',
                exportAs: 'nzbPopover'
            },] },
];
/**
 * @nocollapse
 */
NzbPopoverDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
    { type: NgZone, },
    { type: NzbPopoverOptions, },
];
NzbPopoverDirective.propDecorators = {
    'nzbPopoverTitle': [{ type: Input },],
    'nzbPopoverContent': [{ type: Input },],
    'nzbPopoverOptions': [{ type: Input },],
};

/**
 * @abstract
 */
class NzbAbstractTab {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /**
     * @return {?}
     */
    get data() {
        return this.tabData;
    }
    /**
     * @param {?} tabData
     * @return {?}
     */
    set data(tabData) {
        this.tabData = tabData;
    }
    /**
     * @return {?}
     */
    get el() {
        return this.elementRef.nativeElement;
    }
    /**
     * @abstract
     * @return {?}
     */
    id() { }
}

class NzbTabDirective extends NzbAbstractTab {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        super(elementRef);
    }
    /**
     * @return {?}
     */
    get id() {
        return this.nzbTab;
    }
}
NzbTabDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTab]'
            },] },
];
/**
 * @nocollapse
 */
NzbTabDirective.ctorParameters = () => [
    { type: ElementRef, },
];
NzbTabDirective.propDecorators = {
    'nzbTab': [{ type: Input, args: ['nzbTab',] },],
};

class NzbTabPaneDirective extends NzbAbstractTab {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        super(elementRef);
    }
    /**
     * @return {?}
     */
    get id() {
        return this.nzbTabPane;
    }
}
NzbTabPaneDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTabPane]',
                exportAs: 'nzbTabPane'
            },] },
];
/**
 * @nocollapse
 */
NzbTabPaneDirective.ctorParameters = () => [
    { type: ElementRef, },
];
NzbTabPaneDirective.propDecorators = {
    'nzbTabPane': [{ type: Input, args: ['nzbTabPane',] },],
};

class NzbTabData {
    /**
     * @param {?} tab
     */
    constructor(tab) {
        this.status = null;
        this.active = false;
        this.visible = false;
        this.tab = tab;
        this.id = tab.id;
    }
}

class NzbTabsComponent {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} ngZone
     */
    constructor(elementRef, renderer, ngZone) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.animation = true;
        this.ngUnsubscribe = new EventEmitter();
        this.tabsMap = new Map();
        this.tabsSubject = new BehaviorSubject([]);
        this.activeTabSubject = new BehaviorSubject(null);
        this.eventsSubject = new Subject();
    }
    /**
     * @return {?}
     */
    get tabs() {
        return this.tabsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get activeTab() {
        return this.activeTabSubject.asObservable();
    }
    /**
     * @return {?}
     */
    get events() {
        return this.eventsSubject.asObservable();
    }
    /**
     * @return {?}
     */
    init() {
        const /** @type {?} */ tabs = [];
        const /** @type {?} */ ids = [];
        let /** @type {?} */ activeId = null;
        let /** @type {?} */ activeTab;
        this.tabsMap.clear();
        this.ngZone.runOutsideAngular(() => {
            jQuery(this.elementRef.nativeElement).on('show.bs.tab shown.bs.tab hide.bs.tab hidden.bs.tab', (event) => {
                this.ngZone.run(() => {
                    const /** @type {?} */ id = jQuery(event.target).attr('nzbTab');
                    const /** @type {?} */ data = this.tabsMap.get(id) || null;
                    const /** @type {?} */ tabs = [];
                    if (data) {
                        data.status = event.type;
                        switch (event.type) {
                            case 'hidden':
                                data.visible = false;
                                break;
                            case 'hide':
                                data.active = false;
                                break;
                            case 'show':
                                data.active = true;
                                data.visible = true;
                                this.activeTabSubject.next(data);
                                break;
                        }
                    }
                    this.tabsMap.forEach((entry) => {
                        tabs.push(entry);
                    });
                    this.tabsSubject.next(tabs);
                    this.eventsSubject.next(event);
                });
            });
        });
        this.nzbTabDirectives.forEach((tab) => {
            const /** @type {?} */ tabData = new NzbTabData(tab);
            this.nzbTabPaneDirectives.forEach((pane) => {
                if (pane.id === tab.id) {
                    ids.push(tab.id);
                    tabData.pane = pane;
                    tabs.push(tabData);
                    this.tabsMap.set(tab.id, tabData);
                }
            });
        });
        if (tabs.length > 0) {
            if (typeof this.shownTab === 'string') {
                if (ids.indexOf(this.shownTab) > -1) {
                    activeId = this.shownTab;
                }
            }
            else {
                if (typeof this.shownTab === 'number') {
                    if (this.shownTab < ids.length) {
                        activeId = ids[this.shownTab];
                    }
                }
            }
            if (!activeId) {
                activeId = tabs[0].tab.id;
            }
        }
        tabs.forEach((tab) => {
            const /** @type {?} */ paneId = this.uniqueId + '-' + tab.id;
            const /** @type {?} */ tabId = paneId + '-tab';
            tab.tab.data = tab;
            if (!tab.pane) {
                return;
            }
            tab.pane.data = tab;
            this.renderer.setAttribute(tab.pane.el, 'id', paneId);
            this.renderer.setAttribute(tab.pane.el, 'role', 'tabpanel');
            this.renderer.setAttribute(tab.pane.el, 'aria-labelledby', tabId);
            this.renderer.addClass(tab.pane.el, 'tab-pane');
            if (this.animation) {
                this.renderer.addClass(tab.pane.el, 'fade');
            }
            if (activeId === tab.id) {
                this.renderer.addClass(tab.pane.el, 'active');
                this.renderer.addClass(tab.tab.el, 'active');
                if (this.animation) {
                    this.renderer.addClass(tab.pane.el, 'show');
                }
            }
            this.renderer.setAttribute(tab.tab.el, 'role', 'tab');
            this.renderer.setAttribute(tab.tab.el, 'href', '#' + paneId);
            this.renderer.setAttribute(tab.tab.el, 'aria-controls', paneId);
            this.renderer.setAttribute(tab.tab.el, 'aria-expanded', 'false');
            this.renderer.setAttribute(tab.tab.el, 'id', tabId);
            this.renderer.setAttribute(tab.tab.el, 'data-toggle', 'tab');
            if (activeId === tab.id) {
                activeTab = tab;
            }
        });
        if (activeTab) {
            this.activeTabSubject.next(activeTab);
        }
        this.tabsSubject.next(tabs);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.uniqueId = this.uniqueId || 'nzb-tabs-' + Math.random().toString().replace('.', '');
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        setTimeout(() => {
            Observable.combineLatest(this.nzbTabDirectives.changes, this.nzbTabPaneDirectives.changes)
                .takeUntil(this.ngUnsubscribe)
                .subscribe(() => {
                console.log('got here ngAfterContentInit');
            });
            this.init();
        });
    }
    /**
     * @param {?} id
     * @return {?}
     */
    show(id) {
        const /** @type {?} */ tab = this.tabsMap.get(id);
        if (tab) {
            jQuery(tab.tab.el).tab('show');
        }
    }
}
NzbTabsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nzb-tabs',
                exportAs: 'nzbTabs',
                template: `<ng-content></ng-content>`
            },] },
];
/**
 * @nocollapse
 */
NzbTabsComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: NgZone, },
];
NzbTabsComponent.propDecorators = {
    'animation': [{ type: Input },],
    'uniqueId': [{ type: Input },],
    'shownTab': [{ type: Input },],
    'nzbTabDirectives': [{ type: ContentChildren, args: [NzbTabDirective,] },],
    'nzbTabPaneDirectives': [{ type: ContentChildren, args: [NzbTabPaneDirective,] },],
};

class NzbTooltipOptions extends NzbPopupOptions {
}
NzbTooltipOptions.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NzbTooltipOptions.ctorParameters = () => [];

class NzbTooltipDirective extends NzbAbstractPopup {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     * @param {?} viewContainer
     * @param {?} appRef
     * @param {?} cfr
     * @param {?} ngZone
     * @param {?} defaultOptions
     */
    constructor(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions) {
        super(elementRef, renderer, viewContainer, appRef, cfr, ngZone, defaultOptions);
        this.nzbTooltipTitle = null;
        this.nzbTooltipOptions = null;
        this.bsComponentName = 'tooltip';
    }
    /**
     * @return {?}
     */
    getInputTitleTemplate() {
        return this.nzbTooltipTitle;
    }
    /**
     * @return {?}
     */
    getInputContentTemplate() {
        return null;
    }
    /**
     * @return {?}
     */
    getInputOptions() {
        return this.nzbTooltipOptions;
    }
}
NzbTooltipDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nzbTooltip]',
                exportAs: 'nzbTooltip'
            },] },
];
/**
 * @nocollapse
 */
NzbTooltipDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: ApplicationRef, },
    { type: ComponentFactoryResolver, },
    { type: NgZone, },
    { type: NzbTooltipOptions, },
];
NzbTooltipDirective.propDecorators = {
    'nzbTooltipTitle': [{ type: Input },],
    'nzbTooltipOptions': [{ type: Input },],
};

class NzbModule {
}
NzbModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NzbAlertDirective,
                    NzbCarouselDirective,
                    NzbCollapseDirective,
                    NzbDynamicContentComponent,
                    NzbModalDirective,
                    NzbPopoverDirective,
                    NzbTooltipDirective,
                    NzbTabsComponent,
                    NzbTabPaneDirective,
                    NzbTabDirective,
                    NzbDropdownDirective
                ],
                exports: [
                    NzbAlertDirective,
                    NzbCarouselDirective,
                    NzbCollapseDirective,
                    NzbDynamicContentComponent,
                    NzbModalDirective,
                    NzbPopoverDirective,
                    NzbTooltipDirective,
                    NzbTabsComponent,
                    NzbTabPaneDirective,
                    NzbTabDirective,
                    NzbDropdownDirective
                ],
                providers: [
                    NzbPopoverOptions,
                    NzbTooltipOptions
                ],
                entryComponents: [
                    NzbDynamicContentComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NzbModule.ctorParameters = () => [];

/**
 * Angular library starter.
 * Build an Angular library compatible with AoT compilation & Tree shaking.
 * Written by Roberto Simonetti.
 * MIT license.
 * https://github.com/robisim74/nowzoo-angular-bootstrap-lite
 */
/**
 * Entry point for all public APIs of the package.
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NzbAlertDirective, NzbCarouselDirective, NzbCollapseDirective, NzbDropdownDirective, NzbModalDirective, NzbPopoverDirective, NzbPopoverOptions, NzbTabsComponent, NzbTabPaneDirective, NzbTabDirective, NzbTooltipDirective, NzbTooltipOptions, NzbModule, NzbAbstractPopup as ɵa, NzbDynamicContentComponent as ɵd, NzbPopupOptions as ɵb, NzbAbstractTab as ɵc };
//# sourceMappingURL=nowzoo-angular-bootstrap-lite.js.map
